#!/bin/bash

USAGE="Description:
  Start or restart docker registry, run from a docker container.

Usage:
  '${BASH_SOURCE[0]}' <domain> <ip_address>
"

if [ -z "$1" ] || [ -z "$2" ]
then
	echo "$USAGE"
	exit 1
else
	domain=$1
  ip=$2
fi

main_dir=/var/w3n/${domain}/docker-registry
conf_dir=$main_dir/conf
data_dir=$main_dir/data
if [ ! -d $data_dir ]
then
  echo "Data directory $data_dir doesn't exist"
  exit 1
fi
if [ ! -e $conf_dir/auth/htpasswd ]
then
  echo "File for basic auth $conf_dir/auth/htpasswd doesn't exist"
  exit 1
fi
if [ ! -d $conf_dir/tls ]
then
  echo "Directory with tls certs $conf_dir/tls doesn't exist"
  exit 1
fi


# stop registry, if it runs
running_cont=$(docker ps -f "name=${domain}" -q --no-trunc | head -n1)
if [ -n "$running_cont" ]
then
	echo "Stopping and removing registry container $running_cont"
	docker rm -f $running_cont
fi


# start registry
docker run -d \
  --restart=always \
  --name $domain \
  -v $data_dir:/var/lib/registry \
  -v $conf_dir:/etc/docker/registry \
  -p $ip:443:443 \
  registry:2
