#!/bin/bash

if [ ! -d "$WORK_DIR" ] || [ -z "$STACK" ]
then
	echo "Missing or incorrect static environment variable(s)"
	exit 1
fi

if [ -z "$pipeline" ]
then
	echo "Missing pipeline parameter"
	exit 1
fi

DEPLOYED_DIR="$WORK_DIR/deployed"
DOWNLOAD_DIR="$WORK_DIR/downloads"
FAILED_DIR="$WORK_DIR/failed"
for dir in "$DEPLOYED_DIR" "$DOWNLOAD_DIR" "$FAILED_DIR"
do
	if [ ! -d "$dir" ]
	then
		mkdir "$dir" || exit 1
	fi
done

stack_file="${pipeline}_on_$(date +%Y-%m-%d).yml"
stack_file_path="$DOWNLOAD_DIR/$stack_file"

# save stack file stdin
echo
echo "Saving stack file from stdin as $stack_file"
cat - > "$stack_file_path" || exit 1

echo
echo "Deploying $STACK from $stack_file"
docker stack deploy --with-registry-auth -c "$stack_file_path" $STACK
exit_code=$?

if [ $exit_code -eq 0 ]
then
	mv "$stack_file_path" "$DEPLOYED_DIR/$stack_file"
else
	mv "$stack_file_path" "$FAILED_DIR/$stack_file"
fi
exit $exit_code
